@@ -63,28 +63,34 @@ let owned = dom.take(); // "www.mydomain.com"
 * `serde`: Enables serialization/deserialization support.
 */
 
-#![warn(clippy::filetype_is_file)]
-#![warn(clippy::integer_division)]
-#![warn(clippy::needless_borrow)]
-#![warn(clippy::nursery)]
-#![warn(clippy::pedantic)]
-#![warn(clippy::perf)]
-#![warn(clippy::suboptimal_flops)]
-#![warn(clippy::unneeded_field_pattern)]
-#![warn(macro_use_extern_crate)]
-#![warn(missing_copy_implementations)]
-#![warn(missing_debug_implementations)]
-#![warn(missing_docs)]
-#![warn(non_ascii_idents)]
-#![warn(trivial_casts)]
-#![warn(trivial_numeric_casts)]
-#![warn(unreachable_pub)]
-#![warn(unused_crate_dependencies)]
-#![warn(unused_extern_crates)]
-#![warn(unused_import_braces)]
+#![deny(unsafe_code)]
+
+#![warn(
+	clippy::filetype_is_file,
+	clippy::integer_division,
+	clippy::needless_borrow,
+	clippy::nursery,
+	clippy::pedantic,
+	clippy::perf,
+	clippy::suboptimal_flops,
+	clippy::unneeded_field_pattern,
+	macro_use_extern_crate,
+	missing_copy_implementations,
+	missing_debug_implementations,
+	missing_docs,
+	non_ascii_idents,
+	trivial_casts,
+	trivial_numeric_casts,
+	unreachable_pub,
+	unused_crate_dependencies,
+	unused_extern_crates,
+	unused_import_braces,
+)]
 
 #![allow(clippy::module_name_repetitions)]
 
+#![cfg_attr(feature = "docsrs", feature(doc_cfg))]
+
 
 
 mod idna;
@@ -557,6 +563,7 @@ impl Domain {
 
 
 #[cfg(any(test, feature = "serde"))]
+#[cfg_attr(feature = "docsrs", doc(cfg(feature = "serde")))]
 impl serde::Serialize for Domain {
 	#[inline]
 	/// # Serialize.
@@ -567,6 +574,7 @@ impl serde::Serialize for Domain {
 }
 
 #[cfg(any(test, feature = "serde"))]
+#[cfg_attr(feature = "docsrs", doc(cfg(feature = "serde")))]
 impl<'de> serde::Deserialize<'de> for Domain {
 	/// # Deserialize.
 	///
@@ -580,6 +588,7 @@ impl<'de> serde::Deserialize<'de> for Domain {
 
 
 
+#[allow(unsafe_code)]
 /// # Find Dots.
 ///
 /// The hardest part of suffix validation is teasing the suffix out of the
